@@ -223,7 +223,7 @@ class BackgroundProcess:
         self.thread = None
         self.stdout = []
 
-    def get_stdout(self, sentinel: str | None = None) -> None:
+    def get_stdout(self, sentinel: str='') -> None:
         """Reads stdout from the background process in a separate thread.
         - Optionally, thread returns immediately when a specific sentinel string is found.
         
@@ -232,7 +232,7 @@ class BackgroundProcess:
 
         Returns: None -- thread runs in background reading stdout and appending to self.stdout
         """
-        def read_stdout():
+        def read_stdout(sentinel: str):
             '''Read stdout from the process and optionally wait for a sentinel string
             - Appends lines to self.stdout
             - Exits loop early when sentinel string is found
@@ -241,28 +241,31 @@ class BackgroundProcess:
                 self.stdout.append(line)
                 if sentinel and sentinel in line:
                     break
-        
+
         self.stdout = []
-        self.thread = Thread(target=read_stdout)
-        self.thread.daemon = True
+        self.thread = Thread(target=read_stdout, args=(sentinel,))
         self.thread.start()
-        time.sleep(.1)  # allow thread to start
         return None
 
-    def join_stdout(self, timeout: int | None = None) -> str:
-        """Joins the thread and terminates the process returning the stdout string
+    def join_stdout(self, timeout: int | None = None) -> Tuple[str, str, int, int]:
+        """Joins the thread, waits for the process to terminate
+        - Returns stdout_str, stderr, returncode, pid
         
         Args:
             timeout (int|None): timeout in seconds or block for no timeout
 
         Returns:
-            str: stdout
+            str: stdout_str
+            str: stderr
+            int: returncode
+            int: pid
         """
         if self.thread:
             self.thread.join(timeout=timeout)  # Wait for up to N seconds or block until thread completes
-        stdout_str = ''.join(self.stdout)  # join the stdout lines into a single string
-        self.proc.terminate()
-        return stdout_str
+        # wait for the process to terminate after the thread completes and return stdout_str et al.
+        self.proc.wait()
+        stdout_str = ''.join(self.stdout)  # join the captured stdout lines into a single string
+        return stdout_str, self.proc.stderr, self.proc.returncode, self.proc.pid
 
 
 def shbg(cmd: str, shell=Shell.shell, **kwargs) -> BackgroundProcess:
@@ -278,11 +281,11 @@ def shbg(cmd: str, shell=Shell.shell, **kwargs) -> BackgroundProcess:
     
     Usage:
     ```python
-        bg = shbg('echo -n "hello\\nfrom\\nbackground\\nprocess"; sleep 3')
+        bg = shbg('echo -e "hello\\nfrom\\nbackground\\nprocess"; sleep 3')
         bg.get_stdout(sentinel='back') 
         print('waiting for sentinel ...')
-        stdout = bg.join_stdout(timeout=1)
-        print(stdout) 
+        stdout_str, stderr, rc, pid = bg.join_stdout(timeout=5)
+        print(stdout_str)
     ```
     """
     return BackgroundProcess(cmd, shell, **kwargs)
